@@ -205,7 +205,7 @@ def correlation_heatmap(df,columns,minimum_size=-1,maximum_size=1,**kwargs):
     
 def Heatmap_Survey_group_difference(df,comparison_col_name,comparison_order,choice_col_name,category_col_name,category_order = None,
                                    minimum_size = 5,annot_loc = 10,annotate_dprime = True,annotate_mean_diffs = False,annotate_pvalue_significance = True,
-                                   output_diagnostics = False,significance_level = 0.05):
+                                   output_diagnostics = False,significance_level = 0.05,footnote_x = 0, footnote_y = -0.5,footnote_size=13):
 
     '''
     This function is a heatmap of survey data representing response choices to a particular question. For each category, it
@@ -226,6 +226,9 @@ def Heatmap_Survey_group_difference(df,comparison_col_name,comparison_order,choi
     :param annotate_pvalue_significance. Boolean. Default True
     :param output_diagnostics: Boolean. Default False
     :param significance_level: Float. Default 0.05
+    :param footnote_x: The x coordinate of the footnote
+    :param footnote_y: The y coordinate of the footnote
+    :param footnote_size: The label size of the footnote
     
     :returns: fig
     
